'use strict';

exports.__esModule = true;

var _vue = require('vue');

var _vue2 = _interopRequireDefault(_vue);

var _loading = require('./loading.vue');

var _loading2 = _interopRequireDefault(_loading);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var Instance = _vue2.default.extend(_loading2.default);

var loadingDirective = {};

var defaults = {
  visible: false,
  text: null,
  color: '#ccc',
  iconSize: 15,
  iconColor: '#BA2126',
  img: '',
  imgSize: 40,
  background: 'rgba(255, 255, 255, .8)'
};

loadingDirective.install = function (Vue) {
  Vue.directive('Xloading', {
    bind: function bind(el, params) {
      if (typeof params.value !== 'boolean') return console.error('v-loading请传入布尔值');
      var getParams = {
        visible: params.value,
        text: el.getAttribute('xpx-loading-text'),
        color: el.getAttribute('xpx-loading-text-color') ? el.getAttribute('xpx-loading-text-color') : '#ccc',
        iconSize: el.getAttribute('xpx-loading-icon-size') ? el.getAttribute('xpx-loading-icon-size') : 15,
        iconColor: el.getAttribute('xpx-loading-icon-color') ? el.getAttribute('xpx-loading-icon-color') : '#BA2126',
        img: el.getAttribute('xpx-loading-img'),
        imgSize: el.getAttribute('xpx-loading-img-size') ? el.getAttribute('xpx-loading-img-size') : 40,
        background: el.getAttribute('xpx-loading-bg') ? el.getAttribute('xpx-loading-bg') : 'rgba(255, 255, 255, .8)'
      };
      defaults = Object.assign({}, defaults, getParams);
      var instance = new Instance({
        el: document.createElement('div'),
        data: defaults
      });

      // 绑定close事件
      instance.close = function () {
        this.visible = false;
        setTimeout(function () {
          el.removeChild(el.$loading.$el);
          el.classList.remove('xpx-loading-parent');
        }, 300);
      };

      el.$loading = instance;
      if (params.value) {
        el.appendChild(instance.$el);
        el.classList.add('xpx-loading-parent');
      }
      Vue.nextTick(function () {
        instance.visible = params.value;
      });
      return instance;
    },

    update: function update(el, params) {
      if (typeof params.value !== 'boolean') return console.error('v-loading请传入布尔值');
      if (params.value) {
        el.appendChild(el.$loading.$el);
        el.classList.add('xpx-loading-parent');
        Vue.nextTick(function () {
          el.$loading.visible = true;
        });
      } else {
        if (el === el.$loading.$el.parentNode) el.$loading.close();
      }
    }
  });
};

exports.default = loadingDirective;