/**
 * @Notes: loading
 * @Author: guojinming
 * Date: 2021/7/18 16:00
*/

// 全局变量/常量
const BODY_DOM = document.body;
let oParent = null;

// 默认配置
const loadingGlobal = {
  name: 'default', // 当前loading的名字，标识
  size: 15, // 点点大小
  color: '#BA2126', // 点点颜色
  img: '',  // 图片路径
  imgSize: '', // 图片大小
  text: 'Loading...', // 文字内容
  textColor: '#999', // 文字颜色
  target: '',  // 目标节点
  background: 'rgba(255, 255, 255, .8)'  // 背景色
}

// 生成loading
function Xloading(options = {}) {
  const oMask = document.createElement('div');
  oMask.className = 'full-mask-layer';
  // 当传参只是字符串时，默认为loading的名字
  if (typeof options == "string") options = { name: options }
  // 合并默认配置和传入配置并取出
  options = Object.assign({}, loadingGlobal, options);
  let {name, text, textColor, size, color, img, imgSize, target, background} = options;
  const oPreMask = document.querySelector(`.loading-name--${name}`);
  // 判断有没有指定节点
  oParent = target ? document.querySelector(target) : BODY_DOM;

  if (isChildOf(oPreMask, oParent)) return;

  // size类 可传数字或者字符串，单位px
  size = autoUnit(size);
  imgSize = autoUnit(imgSize);

  // 创建loading-container Dom
  let oCont = document.createElement('div');
  oCont.className = 'loading-container';

  // 如果有图片，替换成传入的图片
  if (img) {
    let oImg = document.createElement('img');
    oImg.className = 'loading-img';
    oImg.src = img;
    if (imgSize) setStyle(oImg, { width: autoUnit(imgSize), height: autoUnit(imgSize) });
    // 将img添加到containerDom上
    oCont.appendChild(oImg);
  } else {
    let imgHTML = `
      <div class="point-wrap">
        <div class="point point1" style="width: ${size}; height: ${size}; background-color: ${color}"></div>
        <div class="point point2" style="width: ${size}; height: ${size}; background-color: ${color}"></div>
        <div class="point point3" style="width: ${size}; height: ${size}; background-color: ${color}"></div>
      </div>
    `;
    oCont.innerHTML = imgHTML;
  }

  if (text) {
    let oP = document.createElement('p');
    oP.className = 'loading-text';
    oP.innerHTML = text;
    setStyle(oP, { color: textColor });
    oCont.appendChild(oP);
  }

  // 最后将container挂载到Mask上，再将mask挂载到body上
  oMask.appendChild(oCont);
  oMask.classList.add(`loading-name--${name}`);
  oParent.appendChild(oMask);
  setTimeout(function() {
    oMask.style.opacity = 1;
    oMask.style.backgroundColor = background;
  }, 0)
  if (oParent == BODY_DOM) {
    oMask.style.position = 'fixed';
    BODY_DOM.classList.add('full-mask-body');
  } else {
    oParent.classList.add('full-mask-parent');
  }
}

// 关闭loading
function CloseXloading(name = 'default') {
  // 移除指定的loading节点
  const oPreMask = document.querySelector(`.loading-name--${name}`);
  if (!oPreMask) return;
  oPreMask.style.opacity = 0;
  setTimeout(() => {
    console.log(`close ${name}`);
    if (isChildOf(oPreMask, oParent)) oParent.removeChild(oPreMask);

    // 判断还有没有其余loading，没有就删除body的class
    const hasMask = document.querySelector(`.full-mask-layer`);
    if (!hasMask) {
      if (oParent == BODY_DOM) {
        BODY_DOM.classList.remove('full-mask-body');
      } else {
        oParent.classList.remove('full-mask-parent');
      }
    }
  }, 500);
}









///////////////////////////////////////////////// utils

// 判断尺寸等值等是否有单位
function autoUnit (val) {
  if (typeof val == 'number') {
    val += 'px'
  } else if (typeof val == 'string') {
    val = val.indexOf('px') == -1 ? val + 'px' : val
  }
  return val
}

// 添加样式
function setStyle (el, styleObj) {
  for (let name in styleObj) {
    el.style[name] = styleObj[name];
  }
}

// 查询是否含有某个子节点
function isChildOf(child, parent) {
  var parentNode;
  if(child && parent) parentNode = child.parentNode;
  return parent === parentNode;
}